pub struct SyncState(/* private fields */);Expand description
SyncState is a structure that holds the state of the syncing process.
The intended use case is to signalize to Web3 API whether the node is fully synced.
Data inside is expected to be updated by both MainNodeFetcher (on last block available on the main node)
and ExternalIO (on latest sealed L2 block).
This structure operates on L2 blocks rather than L1 batches, since this is the default unit used in the web3 API.
Implementations
Sourceimpl SyncState
impl SyncState
pub fn get_main_node_block(&self) -> L2BlockNumber
pub fn get_local_block(&self) -> L2BlockNumber
pub async fn wait_for_local_block(&self, want: L2BlockNumber)
Sourcepub async fn wait_for_main_node_block(
&self,
ctx: &Ctx,
pred: impl Fn(BlockNumber) -> bool,
) -> OrCanceled<BlockNumber>
pub async fn wait_for_main_node_block( &self, ctx: &Ctx, pred: impl Fn(BlockNumber) -> bool, ) -> OrCanceled<BlockNumber>
Waits until the main node block is greater or equal to the given block number. Returns the current main node block number.
pub fn set_main_node_block(&self, block: L2BlockNumber)
pub fn is_synced(&self) -> bool
pub async fn run_updater( self, connection_pool: ConnectionPool<Core>, main_node_client: Box<DynClient<L2>>, stop_receiver: Receiver<bool>, ) -> Result<()>